/**
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.reporting.client;


import com.google.gwt.core.client.GWT;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.uibinder.client.UiTemplate;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.HTML;
import com.google.gwt.user.client.ui.Widget;
import org.ow2.orchestra.common.gwt.utils.client.OrchestraGwtException;
import org.ow2.orchestra.common.gwt.utils.client.ui.popup.Popup;

public class ReportWidget extends Composite {

  @UiField
  HTML displayHtml;
  private String reportName;
  private WebReportAsync reportServlet;

  @UiTemplate("View.ui.xml")
  interface MyUiBinder extends UiBinder<Widget, ReportWidget> {
  }

  private static MyUiBinder uiBinder = GWT.create(MyUiBinder.class);

  public ReportWidget() {

    initWidget(uiBinder.createAndBindUi(this));

    this.reportServlet = (WebReportAsync) GWT.create(WebReport.class);

  }

  public void callReport() {

    reportServlet.getReport(reportName, new AsyncCallback<String>() {

      public void onFailure(Throwable caught) {
        // Insert error message with pop up
        if (caught instanceof OrchestraGwtException) {
          Popup.show((OrchestraGwtException) caught);
        } else {
          Popup.showError(caught.getMessage());
        }

      }

      public void onSuccess(String obj) {
        if (obj != null) {
          displayHtml.setHTML(obj);
        } else {
          displayHtml.setHTML("No content.");
        }
      }
    });
  }


  public String getReportName() {
    return reportName;
  }

  public void setReportName(String reportName) {
    this.reportName = reportName;
  }

}
