/**
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.reporting.server;

import java.util.List;
import org.eclipse.birt.report.engine.api.script.IReportContext;
import org.eclipse.birt.report.engine.api.script.IScriptedDataSetMetaData;
import org.eclipse.birt.report.engine.api.script.IUpdatableDataSetRow;
import org.eclipse.birt.report.engine.api.script.ScriptException;
import org.eclipse.birt.report.engine.api.script.eventadapter.ScriptedDataSetEventAdapter;
import org.eclipse.birt.report.engine.api.script.instance.IDataSetInstance;
import org.ow2.orchestra.common.gwt.utils.server.SessionAPIs;
import org.ow2.orchestra.facade.QueryDefinitionAPI;
import org.ow2.orchestra.facade.def.ProcessDefinition;
import org.ow2.orchestra.facade.def.ProcessState;

public class DataSetEventHandlerProcessStateAll extends
        ScriptedDataSetEventAdapter {

  /**
   * IReportContext is An interface used to share information between the
   * event methods in scripting . Gives access to report parameters and
   * configuration values. Also provides a way for the report developer to
   * register and retrieve custom properties.
   */


  final static String PROCESS_STATE_COLUMN_NAME = "PROCESS_STATE";   // This value must be exactly the same in the matching alias column on Birt's Data set
  private SessionAPIs sessionAPIs;
  private int processesCount;
  private List<ProcessDefinition> processes;

  public DataSetEventHandlerProcessStateAll() {
  }

  /**
   * The open method is called when the data set is opened, use this method
   * to initialize variables and to prepare for fetching rows
   * Need to add throws exception in each
   */
  @Override
  public void open(IDataSetInstance dataSet) throws ScriptException  {
    this.processesCount = 0;
    QueryDefinitionAPI api;
    api = sessionAPIs.getAPI(QueryDefinitionAPI.class);
    processes = api.findProcessDefinitions();
  }

  public boolean fetch(IDataSetInstance dataSet, IUpdatableDataSetRow row) throws ScriptException {
    if (processes != null) {
      if (processesCount < processes.size()) {
        if (ProcessState.ACTIVE.equals(processes.get(processesCount).getState())) {
          row.setColumnValue(PROCESS_STATE_COLUMN_NAME, "Active");
        } else if (ProcessState.RETIRED.equals(processes.get(processesCount).getState())) {
          row.setColumnValue(PROCESS_STATE_COLUMN_NAME, "Retired");
        } else {
          row.setColumnValue(PROCESS_STATE_COLUMN_NAME, "Undeployed");
        }
        processesCount++;
        return true;
      }
    }
    return false;
  }

  @Override
  public boolean describe(IDataSetInstance dataSet, IScriptedDataSetMetaData metaData) throws ScriptException {
    super.describe(dataSet, metaData);
    metaData.addColumn(PROCESS_STATE_COLUMN_NAME, String.class);
    return true;
  }

  @Override
  public void beforeOpen(IDataSetInstance dataSet, IReportContext reportContext) throws ScriptException {
    /**
     * IReportContext is the report context used to evaluate the java-based
     * script.
     */
    super.beforeOpen(dataSet, reportContext);
    this.sessionAPIs = (SessionAPIs) reportContext.getParameterValue("PARAMBIRT_ORCHESTRA_SESSION_API");
  }

  @Override
  public void close(IDataSetInstance dataSet) throws ScriptException {
    super.close(dataSet);
  }
}
